pub async fn exchange_manifest_code(code: &str) -> Result<AppCredentials>Expand description
Exchange a one-time code from the manifest redirect for permanent app
credentials. The code is single-use and expires within 1 hour.
pub async fn exchange_manifest_code(code: &str) -> Result<AppCredentials>Exchange a one-time code from the manifest redirect for permanent app
credentials. The code is single-use and expires within 1 hour.