pub async fn install_on_repos(
creds: &AppCredentials,
owner: &str,
_app_slug: &str,
repos: &[String],
) -> Result<()>Expand description
Add a list of repos to an existing installation. Idempotent — GitHub returns 204 even if a repo is already in the installation.